@@ -151,9 +151,8 @@ find_partner (struct BenchmarkPeer *me,
   for (c_m = 0; c_m < me->num_partners; c_m++)
   {
     /* Find a partner with other as destination */
-    if (0 == memcmp (peer,
-		     &me->partners[c_m].dest->id,
-		     sizeof (struct GNUNET_PeerIdentity)))
+    if (0 == GNUNET_memcmp (peer,
+		     &me->partners[c_m].dest->id))
     {
       return &me->partners[c_m];
     }
@@ -170,17 +169,15 @@ find_peer (const struct GNUNET_PeerIdentity * peer)
 
   for (c_p = 0; c_p < top->num_masters; c_p++)
   {
-    if (0 == memcmp (&top->mps[c_p].id,
-		     peer,
-		     sizeof(struct GNUNET_PeerIdentity)))
+    if (0 == GNUNET_memcmp (&top->mps[c_p].id,
+		     peer))
       return &top->mps[c_p];
   }
 
   for (c_p = 0; c_p < top->num_slaves; c_p++)
   {
-    if (0 == memcmp (&top->sps[c_p].id,
-		     peer,
-		     sizeof(struct GNUNET_PeerIdentity)))
+    if (0 == GNUNET_memcmp (&top->sps[c_p].id,
+		     peer))
       return &top->sps[c_p];
   }
   return NULL ;
