@@ -32,7 +32,7 @@
 #include "gnunet_nse_service.h"
 #include "nse.h"
 
-#define LOG(kind,...) GNUNET_log_from (kind, "nse-api",__VA_ARGS__)
+#define LOG(kind, ...) GNUNET_log_from (kind, "nse-api", __VA_ARGS__)
 
 /**
  * Handle for talking with the NSE service.
@@ -68,7 +68,6 @@ struct GNUNET_NSE_Handle
    * Closure to pass to @e recv_cb callback.
    */
   void *recv_cb_cls;
-
 };
 
 
@@ -91,17 +90,15 @@ reconnect (void *cls);
  * @param error error code
  */
 static void
-mq_error_handler (void *cls,
-                  enum GNUNET_MQ_Error error)
+mq_error_handler (void *cls, enum GNUNET_MQ_Error error)
 {
   struct GNUNET_NSE_Handle *h = cls;
 
+  (void) error;
   GNUNET_MQ_destroy (h->mq);
   h->mq = NULL;
-  h->reconnect_task
-    = GNUNET_SCHEDULER_add_delayed (h->reconnect_delay,
-                                    &reconnect,
-                                    h);
+  h->reconnect_task =
+    GNUNET_SCHEDULER_add_delayed (h->reconnect_delay, &reconnect, h);
   h->reconnect_delay = GNUNET_TIME_STD_BACKOFF (h->reconnect_delay);
 }
 
@@ -114,8 +111,7 @@ mq_error_handler (void *cls,
  * @param client_msg message received
  */
 static void
-handle_estimate (void *cls,
-		 const struct GNUNET_NSE_ClientMessage *client_msg)
+handle_estimate (void *cls, const struct GNUNET_NSE_ClientMessage *client_msg)
 {
   struct GNUNET_NSE_Handle *h = cls;
 
@@ -123,7 +119,7 @@ handle_estimate (void *cls,
   h->recv_cb (h->recv_cb_cls,
               GNUNET_TIME_absolute_ntoh (client_msg->timestamp),
               GNUNET_ntoh_double (client_msg->size_estimate),
-	      GNUNET_ntoh_double (client_msg->std_deviation));
+              GNUNET_ntoh_double (client_msg->std_deviation));
 }
 
 
@@ -136,13 +132,12 @@ static void
 reconnect (void *cls)
 {
   struct GNUNET_NSE_Handle *h = cls;
-  struct GNUNET_MQ_MessageHandler handlers[] = {
-    GNUNET_MQ_hd_fixed_size (estimate,
-                             GNUNET_MESSAGE_TYPE_NSE_ESTIMATE,
-                             struct GNUNET_NSE_ClientMessage,
-                             h),
-    GNUNET_MQ_handler_end ()
-  };
+  struct GNUNET_MQ_MessageHandler handlers[] =
+    {GNUNET_MQ_hd_fixed_size (estimate,
+                              GNUNET_MESSAGE_TYPE_NSE_ESTIMATE,
+                              struct GNUNET_NSE_ClientMessage,
+                              h),
+     GNUNET_MQ_handler_end ()};
   struct GNUNET_MessageHeader *msg;
   struct GNUNET_MQ_Envelope *env;
 
@@ -150,17 +145,11 @@ reconnect (void *cls)
   LOG (GNUNET_ERROR_TYPE_DEBUG,
        "Connecting to network size estimation service.\n");
   GNUNET_assert (NULL == h->mq);
-  h->mq = GNUNET_CLIENT_connect (h->cfg,
-                                 "nse",
-                                 handlers,
-                                 &mq_error_handler,
-                                 h);
+  h->mq = GNUNET_CLIENT_connect (h->cfg, "nse", handlers, &mq_error_handler, h);
   if (NULL == h->mq)
     return;
-  env = GNUNET_MQ_msg (msg,
-                       GNUNET_MESSAGE_TYPE_NSE_START);
-  GNUNET_MQ_send (h->mq,
-                  env);
+  env = GNUNET_MQ_msg (msg, GNUNET_MESSAGE_TYPE_NSE_START);
+  GNUNET_MQ_send (h->mq, env);
 }
 
 
