@@ -28,7 +28,7 @@
 #include "peerstore.h"
 #include "peerstore_common.h"
 
-#define LOG(kind,...) GNUNET_log_from (kind, "peerstore-api",__VA_ARGS__)
+#define LOG(kind, ...) GNUNET_log_from (kind, "peerstore-api", __VA_ARGS__)
 
 /******************************************************************************/
 /************************      DATA STRUCTURES     ****************************/
@@ -89,7 +89,6 @@ struct GNUNET_PEERSTORE_Handle
    * Are we in the process of disconnecting but need to sync first?
    */
   int disconnecting;
-
 };
 
 /**
@@ -156,7 +155,6 @@ struct GNUNET_PEERSTORE_StoreContext
    * Options for the store operation.
    */
   enum GNUNET_PEERSTORE_StoreOption options;
-
 };
 
 /**
@@ -208,7 +206,6 @@ struct GNUNET_PEERSTORE_IterateContext
    * #GNUNET_YES if we are currently processing records.
    */
   int iterating;
-
 };
 
 /**
@@ -245,7 +242,6 @@ struct GNUNET_PEERSTORE_WatchContext
    * Hash of the combined key
    */
   struct GNUNET_HashCode keyhash;
-
 };
 
 /******************************************************************************/
@@ -271,8 +267,7 @@ disconnect (struct GNUNET_PEERSTORE_Handle *h)
 {
   struct GNUNET_PEERSTORE_IterateContext *next;
 
-  for (struct GNUNET_PEERSTORE_IterateContext *ic = h->iterate_head;
-       NULL != ic;
+  for (struct GNUNET_PEERSTORE_IterateContext *ic = h->iterate_head; NULL != ic;
        ic = next)
   {
     next = ic->next;
@@ -285,9 +280,7 @@ disconnect (struct GNUNET_PEERSTORE_Handle *h)
       icb_cls = ic->callback_cls;
       GNUNET_PEERSTORE_iterate_cancel (ic);
       if (NULL != icb)
-        icb (icb_cls,
-             NULL,
-             "Iteration canceled due to reconnection");
+        icb (icb_cls, NULL, "Iteration canceled due to reconnection");
     }
   }
 
@@ -312,17 +305,13 @@ disconnect_and_schedule_reconnect (struct GNUNET_PEERSTORE_Handle *h)
   disconnect (h);
   LOG (GNUNET_ERROR_TYPE_DEBUG,
        "Scheduling task to reconnect to PEERSTORE service in %s.\n",
-       GNUNET_STRINGS_relative_time_to_string (h->reconnect_delay,
-                                               GNUNET_YES));
+       GNUNET_STRINGS_relative_time_to_string (h->reconnect_delay, GNUNET_YES));
   h->reconnect_task =
-      GNUNET_SCHEDULER_add_delayed (h->reconnect_delay,
-                                    &reconnect,
-                                    h);
+    GNUNET_SCHEDULER_add_delayed (h->reconnect_delay, &reconnect, h);
   h->reconnect_delay = GNUNET_TIME_STD_BACKOFF (h->reconnect_delay);
 }
 
 
-
 /**
  * Callback after MQ envelope is sent
  *
@@ -352,8 +341,7 @@ store_request_sent (void *cls)
  * Function called when we had trouble talking to the service.
  */
 static void
-handle_client_error (void *cls,
-                     enum GNUNET_MQ_Error error)
+handle_client_error (void *cls, enum GNUNET_MQ_Error error)
 {
   struct GNUNET_PEERSTORE_Handle *h = cls;
 
@@ -373,9 +361,7 @@ handle_client_error (void *cls,
  * @return #GNUNET_YES (continue to iterate)
  */
 static int
-rewatch_it (void *cls,
-	    const struct GNUNET_HashCode *key,
-	    void *value)
+rewatch_it (void *cls, const struct GNUNET_HashCode *key, void *value)
 {
   struct GNUNET_PEERSTORE_Handle *h = cls;
   struct GNUNET_PEERSTORE_WatchContext *wc = value;
@@ -398,9 +384,7 @@ rewatch_it (void *cls,
  * @return #GNUNET_YES to continue iteration
  */
 static int
-destroy_watch (void *cls,
-               const struct GNUNET_HashCode *key,
-               void *value)
+destroy_watch (void *cls, const struct GNUNET_HashCode *key, void *value)
 {
   struct GNUNET_PEERSTORE_WatchContext *wc = value;
 
@@ -461,8 +445,7 @@ GNUNET_PEERSTORE_connect (const struct GNUNET_CONFIGURATION_Handle *cfg)
  * @param sync_first send any pending STORE requests before disconnecting
  */
 void
-GNUNET_PEERSTORE_disconnect (struct GNUNET_PEERSTORE_Handle *h,
-                             int sync_first)
+GNUNET_PEERSTORE_disconnect (struct GNUNET_PEERSTORE_Handle *h, int sync_first)
 {
   struct GNUNET_PEERSTORE_IterateContext *ic;
   struct GNUNET_PEERSTORE_StoreContext *sc;
@@ -515,8 +498,7 @@ GNUNET_PEERSTORE_store_cancel (struct GNUNET_PEERSTORE_StoreContext *sc)
   GNUNET_free (sc->value);
   GNUNET_free (sc->key);
   GNUNET_free (sc);
-  if ( (GNUNET_YES == h->disconnecting) &&
-       (NULL == h->store_head) )
+  if ((GNUNET_YES == h->disconnecting) && (NULL == h->store_head))
     final_disconnect (h);
 }
 
@@ -542,7 +524,8 @@ GNUNET_PEERSTORE_store (struct GNUNET_PEERSTORE_Handle *h,
                         const char *sub_system,
                         const struct GNUNET_PeerIdentity *peer,
                         const char *key,
-                        const void *value, size_t size,
+                        const void *value,
+                        size_t size,
                         struct GNUNET_TIME_Absolute expiry,
                         enum GNUNET_PEERSTORE_StoreOption options,
                         GNUNET_PEERSTORE_Continuation cont,
@@ -553,10 +536,19 @@ GNUNET_PEERSTORE_store (struct GNUNET_PEERSTORE_Handle *h,
 
   LOG (GNUNET_ERROR_TYPE_DEBUG,
        "Storing value (size: %lu) for subsytem `%s', peer `%s', key `%s'\n",
-       size, sub_system, GNUNET_i2s (peer), key);
-  ev = PEERSTORE_create_record_mq_envelope (sub_system, peer, key, value, size,
-                                            expiry, options,
-                                            GNUNET_MESSAGE_TYPE_PEERSTORE_STORE);
+       size,
+       sub_system,
+       GNUNET_i2s (peer),
+       key);
+  ev =
+    PEERSTORE_create_record_mq_envelope (sub_system,
+                                         peer,
+                                         key,
+                                         value,
+                                         size,
+                                         expiry,
+                                         options,
+                                         GNUNET_MESSAGE_TYPE_PEERSTORE_STORE);
   sc = GNUNET_new (struct GNUNET_PEERSTORE_StoreContext);
 
   sc->sub_system = GNUNET_strdup (sub_system);
@@ -574,7 +566,6 @@ GNUNET_PEERSTORE_store (struct GNUNET_PEERSTORE_Handle *h,
   GNUNET_MQ_notify_sent (ev, &store_request_sent, sc);
   GNUNET_MQ_send (h->mq, ev);
   return sc;
-
 }
 
 
@@ -590,8 +581,7 @@ GNUNET_PEERSTORE_store (struct GNUNET_PEERSTORE_Handle *h,
  * @param msg message received
  */
 static void
-handle_iterate_end (void *cls,
-                    const struct GNUNET_MessageHeader *msg)
+handle_iterate_end (void *cls, const struct GNUNET_MessageHeader *msg)
 {
   struct GNUNET_PEERSTORE_Handle *h = cls;
   struct GNUNET_PEERSTORE_IterateContext *ic;
@@ -602,7 +592,7 @@ handle_iterate_end (void *cls,
   if (NULL == ic)
   {
     LOG (GNUNET_ERROR_TYPE_ERROR,
-         _("Unexpected iteration response, this should not happen.\n"));
+         _ ("Unexpected iteration response, this should not happen.\n"));
     disconnect_and_schedule_reconnect (h);
     return;
   }
@@ -611,9 +601,7 @@ handle_iterate_end (void *cls,
   ic->iterating = GNUNET_NO;
   GNUNET_PEERSTORE_iterate_cancel (ic);
   if (NULL != callback)
-    callback (callback_cls,
-              NULL,
-              NULL);
+    callback (callback_cls, NULL, NULL);
   h->reconnect_delay = GNUNET_TIME_UNIT_ZERO;
 }
 
@@ -626,8 +614,7 @@ handle_iterate_end (void *cls,
  * @param msg message received
  */
 static int
-check_iterate_result (void *cls,
-                      const struct StoreRecordMessage *msg)
+check_iterate_result (void *cls, const struct StoreRecordMessage *msg)
 {
   /* we defer validation to #handle_iterate_result */
   return GNUNET_OK;
@@ -641,8 +628,7 @@ check_iterate_result (void *cls,
  * @param msg message received
  */
 static void
-handle_iterate_result (void *cls,
-                       const struct StoreRecordMessage *msg)
+handle_iterate_result (void *cls, const struct StoreRecordMessage *msg)
 {
   struct GNUNET_PEERSTORE_Handle *h = cls;
   struct GNUNET_PEERSTORE_IterateContext *ic;
@@ -654,7 +640,7 @@ handle_iterate_result (void *cls,
   if (NULL == ic)
   {
     LOG (GNUNET_ERROR_TYPE_ERROR,
-         _("Unexpected iteration response, this should not happen.\n"));
+         _ ("Unexpected iteration response, this should not happen.\n"));
     disconnect_and_schedule_reconnect (h);
     return;
   }
@@ -668,13 +654,11 @@ handle_iterate_result (void *cls,
   {
     callback (callback_cls,
               NULL,
-              _("Received a malformed response from service."));
+              _ ("Received a malformed response from service."));
   }
   else
   {
-    callback (callback_cls,
-              record,
-              NULL);
+    callback (callback_cls, record, NULL);
     PEERSTORE_destroy_record (record);
   }
 }
@@ -691,9 +675,7 @@ GNUNET_PEERSTORE_iterate_cancel (struct GNUNET_PEERSTORE_IterateContext *ic)
 {
   if (GNUNET_NO == ic->iterating)
   {
-    GNUNET_CONTAINER_DLL_remove (ic->h->iterate_head,
-                                 ic->h->iterate_tail,
-                                 ic);
+    GNUNET_CONTAINER_DLL_remove (ic->h->iterate_head, ic->h->iterate_tail, ic);
     GNUNET_free (ic->sub_system);
     GNUNET_free_non_null (ic->key);
     GNUNET_free (ic);
@@ -725,13 +707,15 @@ GNUNET_PEERSTORE_iterate (struct GNUNET_PEERSTORE_Handle *h,
   struct GNUNET_MQ_Envelope *ev;
   struct GNUNET_PEERSTORE_IterateContext *ic;
 
-  ev = PEERSTORE_create_record_mq_envelope (sub_system,
-                                            peer,
-                                            key,
-                                            NULL, 0,
-                                            GNUNET_TIME_UNIT_FOREVER_ABS,
-                                            0,
-                                            GNUNET_MESSAGE_TYPE_PEERSTORE_ITERATE);
+  ev =
+    PEERSTORE_create_record_mq_envelope (sub_system,
+                                         peer,
+                                         key,
+                                         NULL,
+                                         0,
+                                         GNUNET_TIME_UNIT_FOREVER_ABS,
+                                         0,
+                                         GNUNET_MESSAGE_TYPE_PEERSTORE_ITERATE);
   ic = GNUNET_new (struct GNUNET_PEERSTORE_IterateContext);
   ic->callback = callback;
   ic->callback_cls = callback_cls;
@@ -741,9 +725,7 @@ GNUNET_PEERSTORE_iterate (struct GNUNET_PEERSTORE_Handle *h,
     ic->peer = *peer;
   if (NULL != key)
     ic->key = GNUNET_strdup (key);
-  GNUNET_CONTAINER_DLL_insert_tail (h->iterate_head,
-                                    h->iterate_tail,
-                                    ic);
+  GNUNET_CONTAINER_DLL_insert_tail (h->iterate_head, h->iterate_tail, ic);
   LOG (GNUNET_ERROR_TYPE_DEBUG,
        "Sending an iterate request for sub system `%s'\n",
        sub_system);
@@ -763,8 +745,7 @@ GNUNET_PEERSTORE_iterate (struct GNUNET_PEERSTORE_Handle *h,
  * @param msg message received
  */
 static int
-check_watch_record (void *cls,
-                    const struct StoreRecordMessage *msg)
+check_watch_record (void *cls, const struct StoreRecordMessage *msg)
 {
   /* we defer validation to #handle_watch_result */
   return GNUNET_OK;
@@ -778,41 +759,33 @@ check_watch_record (void *cls,
  * @param msg message received
  */
 static void
-handle_watch_record (void *cls,
-                     const struct StoreRecordMessage *msg)
+handle_watch_record (void *cls, const struct StoreRecordMessage *msg)
 {
   struct GNUNET_PEERSTORE_Handle *h = cls;
   struct GNUNET_PEERSTORE_Record *record;
   struct GNUNET_HashCode keyhash;
   struct GNUNET_PEERSTORE_WatchContext *wc;
 
-  LOG (GNUNET_ERROR_TYPE_DEBUG,
-       "Received a watch record from service.\n");
+  LOG (GNUNET_ERROR_TYPE_DEBUG, "Received a watch record from service.\n");
   record = PEERSTORE_parse_record_message (msg);
   if (NULL == record)
   {
     disconnect_and_schedule_reconnect (h);
     return;
   }
-  PEERSTORE_hash_key (record->sub_system,
-                      &record->peer,
-                      record->key,
-                      &keyhash);
+  PEERSTORE_hash_key (record->sub_system, &record->peer, record->key, &keyhash);
   // FIXME: what if there are multiple watches for the same key?
-  wc = GNUNET_CONTAINER_multihashmap_get (h->watches,
-                                          &keyhash);
+  wc = GNUNET_CONTAINER_multihashmap_get (h->watches, &keyhash);
   if (NULL == wc)
   {
     LOG (GNUNET_ERROR_TYPE_ERROR,
-         _("Received a watch result for a non existing watch.\n"));
+         _ ("Received a watch result for a non existing watch.\n"));
     PEERSTORE_destroy_record (record);
     disconnect_and_schedule_reconnect (h);
     return;
   }
   if (NULL != wc->callback)
-    wc->callback (wc->callback_cls,
-                  record,
-                  NULL);
+    wc->callback (wc->callback_cls, record, NULL);
   h->reconnect_delay = GNUNET_TIME_UNIT_ZERO;
   PEERSTORE_destroy_record (record);
 }
@@ -827,26 +800,24 @@ static void
 reconnect (void *cls)
 {
   struct GNUNET_PEERSTORE_Handle *h = cls;
-  struct GNUNET_MQ_MessageHandler mq_handlers[] = {
-    GNUNET_MQ_hd_fixed_size (iterate_end,
-                             GNUNET_MESSAGE_TYPE_PEERSTORE_ITERATE_END,
-                             struct GNUNET_MessageHeader,
-                             h),
-    GNUNET_MQ_hd_var_size (iterate_result,
-                           GNUNET_MESSAGE_TYPE_PEERSTORE_ITERATE_RECORD,
-                           struct StoreRecordMessage,
-                           h),
-    GNUNET_MQ_hd_var_size (watch_record,
-                           GNUNET_MESSAGE_TYPE_PEERSTORE_WATCH_RECORD,
-                           struct StoreRecordMessage,
-                           h),
-    GNUNET_MQ_handler_end ()
-  };
+  struct GNUNET_MQ_MessageHandler mq_handlers[] =
+    {GNUNET_MQ_hd_fixed_size (iterate_end,
+                              GNUNET_MESSAGE_TYPE_PEERSTORE_ITERATE_END,
+                              struct GNUNET_MessageHeader,
+                              h),
+     GNUNET_MQ_hd_var_size (iterate_result,
+                            GNUNET_MESSAGE_TYPE_PEERSTORE_ITERATE_RECORD,
+                            struct StoreRecordMessage,
+                            h),
+     GNUNET_MQ_hd_var_size (watch_record,
+                            GNUNET_MESSAGE_TYPE_PEERSTORE_WATCH_RECORD,
+                            struct StoreRecordMessage,
+                            h),
+     GNUNET_MQ_handler_end ()};
   struct GNUNET_MQ_Envelope *ev;
 
   h->reconnect_task = NULL;
-  LOG (GNUNET_ERROR_TYPE_DEBUG,
-       "Reconnecting...\n");
+  LOG (GNUNET_ERROR_TYPE_DEBUG, "Reconnecting...\n");
   h->mq = GNUNET_CLIENT_connect (h->cfg,
                                  "peerstore",
                                  mq_handlers,
@@ -857,39 +828,35 @@ reconnect (void *cls)
   LOG (GNUNET_ERROR_TYPE_DEBUG,
        "Resending pending requests after reconnect.\n");
   if (NULL != h->watches)
-    GNUNET_CONTAINER_multihashmap_iterate (h->watches,
-                                           &rewatch_it,
-                                           h);
-  for (struct GNUNET_PEERSTORE_IterateContext *ic = h->iterate_head;
-       NULL != ic;
+    GNUNET_CONTAINER_multihashmap_iterate (h->watches, &rewatch_it, h);
+  for (struct GNUNET_PEERSTORE_IterateContext *ic = h->iterate_head; NULL != ic;
        ic = ic->next)
   {
-    ev = PEERSTORE_create_record_mq_envelope (ic->sub_system,
-                                              &ic->peer,
-                                              ic->key,
-                                              NULL, 0,
-                                              GNUNET_TIME_UNIT_FOREVER_ABS,
-                                              0,
-                                              GNUNET_MESSAGE_TYPE_PEERSTORE_ITERATE);
+    ev =
+      PEERSTORE_create_record_mq_envelope (ic->sub_system,
+                                           &ic->peer,
+                                           ic->key,
+                                           NULL,
+                                           0,
+                                           GNUNET_TIME_UNIT_FOREVER_ABS,
+                                           0,
+                                           GNUNET_MESSAGE_TYPE_PEERSTORE_ITERATE);
     GNUNET_MQ_send (h->mq, ev);
   }
-  for (struct GNUNET_PEERSTORE_StoreContext *sc = h->store_head;
-       NULL != sc;
+  for (struct GNUNET_PEERSTORE_StoreContext *sc = h->store_head; NULL != sc;
        sc = sc->next)
   {
-    ev = PEERSTORE_create_record_mq_envelope (sc->sub_system,
-                                              &sc->peer,
-                                              sc->key,
-                                              sc->value,
-                                              sc->size,
-                                              sc->expiry,
-                                              sc->options,
-                                              GNUNET_MESSAGE_TYPE_PEERSTORE_STORE);
-    GNUNET_MQ_notify_sent (ev,
-                           &store_request_sent,
-                           sc);
-    GNUNET_MQ_send (h->mq,
-                    ev);
+    ev =
+      PEERSTORE_create_record_mq_envelope (sc->sub_system,
+                                           &sc->peer,
+                                           sc->key,
+                                           sc->value,
+                                           sc->size,
+                                           sc->expiry,
+                                           sc->options,
+                                           GNUNET_MESSAGE_TYPE_PEERSTORE_STORE);
+    GNUNET_MQ_notify_sent (ev, &store_request_sent, sc);
+    GNUNET_MQ_send (h->mq, ev);
   }
 }
 
@@ -906,15 +873,13 @@ GNUNET_PEERSTORE_watch_cancel (struct GNUNET_PEERSTORE_WatchContext *wc)
   struct GNUNET_MQ_Envelope *ev;
   struct StoreKeyHashMessage *hm;
 
-  LOG (GNUNET_ERROR_TYPE_DEBUG,
-       "Canceling watch.\n");
-  ev = GNUNET_MQ_msg (hm,
-                      GNUNET_MESSAGE_TYPE_PEERSTORE_WATCH_CANCEL);
+  LOG (GNUNET_ERROR_TYPE_DEBUG, "Canceling watch.\n");
+  ev = GNUNET_MQ_msg (hm, GNUNET_MESSAGE_TYPE_PEERSTORE_WATCH_CANCEL);
   hm->keyhash = wc->keyhash;
   GNUNET_MQ_send (h->mq, ev);
-  GNUNET_CONTAINER_multihashmap_remove (h->watches,
-                                        &wc->keyhash,
-                                        wc);
+  GNUNET_assert (
+    GNUNET_YES ==
+    GNUNET_CONTAINER_multihashmap_remove (h->watches, &wc->keyhash, wc));
   GNUNET_free (wc);
 }
 
@@ -943,32 +908,26 @@ GNUNET_PEERSTORE_watch (struct GNUNET_PEERSTORE_Handle *h,
   struct StoreKeyHashMessage *hm;
   struct GNUNET_PEERSTORE_WatchContext *wc;
 
-  ev = GNUNET_MQ_msg (hm,
-                      GNUNET_MESSAGE_TYPE_PEERSTORE_WATCH);
-  PEERSTORE_hash_key (sub_system,
-                      peer,
-                      key,
-                      &hm->keyhash);
+  ev = GNUNET_MQ_msg (hm, GNUNET_MESSAGE_TYPE_PEERSTORE_WATCH);
+  PEERSTORE_hash_key (sub_system, peer, key, &hm->keyhash);
   wc = GNUNET_new (struct GNUNET_PEERSTORE_WatchContext);
   wc->callback = callback;
   wc->callback_cls = callback_cls;
   wc->h = h;
   wc->keyhash = hm->keyhash;
   if (NULL == h->watches)
-    h->watches = GNUNET_CONTAINER_multihashmap_create (5,
-                                                       GNUNET_NO);
-  GNUNET_assert (GNUNET_OK ==
-                 GNUNET_CONTAINER_multihashmap_put (h->watches,
-                                                    &wc->keyhash,
-                                                    wc,
-                                                    GNUNET_CONTAINER_MULTIHASHMAPOPTION_MULTIPLE));
+    h->watches = GNUNET_CONTAINER_multihashmap_create (5, GNUNET_NO);
+  GNUNET_assert (GNUNET_OK == GNUNET_CONTAINER_multihashmap_put (
+                                h->watches,
+                                &wc->keyhash,
+                                wc,
+                                GNUNET_CONTAINER_MULTIHASHMAPOPTION_MULTIPLE));
   LOG (GNUNET_ERROR_TYPE_DEBUG,
        "Sending a watch request for subsystem `%s', peer `%s', key `%s'.\n",
        sub_system,
        GNUNET_i2s (peer),
        key);
-  GNUNET_MQ_send (h->mq,
-                  ev);
+  GNUNET_MQ_send (h->mq, ev);
   return wc;
 }
 
