@@ -462,8 +462,9 @@ GNUNET_TESTBED_hosts_load_from_file (const char *filename,
       {
         size = pmatch[2].rm_eo - pmatch[2].rm_so;
         username = GNUNET_malloc (size + 1);
-        username[size] = '\0';
-        GNUNET_assert (NULL != strncpy (username, buf + pmatch[2].rm_so, size));
+        GNUNET_assert(0 != GNUNET_strlcpy (username,
+                                           buf + pmatch[2].rm_so,
+                                           size + 1));
       }
       if (-1 != pmatch[5].rm_so)
       {
@@ -471,8 +472,9 @@ GNUNET_TESTBED_hosts_load_from_file (const char *filename,
       }
       size = pmatch[3].rm_eo - pmatch[3].rm_so;
       hostname = GNUNET_malloc (size + 1);
-      hostname[size] = '\0';
-      GNUNET_assert (NULL != strncpy (hostname, buf + pmatch[3].rm_so, size));
+      GNUNET_assert(0 != GNUNET_strlcpy (hostname,
+                                         buf + pmatch[3].rm_so,
+                                         size + 1));
       LOG (GNUNET_ERROR_TYPE_DEBUG,
            "Successfully read host %s, port %d and user %s from file\n",
            (NULL == hostname) ? "NULL" : hostname,
