@@ -11,7 +11,7 @@
      WITHOUT ANY WARRANTY; without even the implied warranty of
      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
      Affero General Public License for more details.
-    
+
      You should have received a copy of the GNU Affero General Public License
      along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
@@ -51,12 +51,14 @@
 /**
  * At what frequency do we sent HELLOs to a peer?
  */
-#define HELLO_ADVERTISEMENT_MIN_FREQUENCY GNUNET_TIME_relative_multiply (GNUNET_TIME_UNIT_MINUTES, 5)
+#define HELLO_ADVERTISEMENT_MIN_FREQUENCY \
+  GNUNET_TIME_relative_multiply (GNUNET_TIME_UNIT_MINUTES, 5)
 
 /**
  * After what time period do we expire the HELLO Bloom filter?
  */
-#define HELLO_ADVERTISEMENT_MIN_REPEAT_FREQUENCY GNUNET_TIME_relative_multiply (GNUNET_TIME_UNIT_HOURS, 4)
+#define HELLO_ADVERTISEMENT_MIN_REPEAT_FREQUENCY \
+  GNUNET_TIME_relative_multiply (GNUNET_TIME_UNIT_HOURS, 4)
 
 
 /**
@@ -116,7 +118,6 @@ struct Peer
    * Is this peer listed here because it is a friend?
    */
   int is_friend;
-
 };
 
 
@@ -216,15 +217,12 @@ static unsigned int friend_count;
  * @return #GNUNET_OK if the connection is allowed
  */
 static int
-blacklist_check (void *cls,
-                 const struct GNUNET_PeerIdentity *pid)
+blacklist_check (void *cls, const struct GNUNET_PeerIdentity *pid)
 {
   struct Peer *pos;
 
-  pos = GNUNET_CONTAINER_multipeermap_get (peers,
-                                           pid);
-  if ( (NULL != pos) &&
-       (GNUNET_YES == pos->is_friend))
+  pos = GNUNET_CONTAINER_multipeermap_get (peers, pid);
+  if ((NULL != pos) && (GNUNET_YES == pos->is_friend))
     return GNUNET_OK;
   GNUNET_STATISTICS_update (stats,
                             gettext_noop ("# peers blacklisted"),
@@ -258,17 +256,13 @@ whitelist_peers ()
  * @return #GNUNET_YES (always: continue to iterate)
  */
 static int
-free_peer (void *cls,
-           const struct GNUNET_PeerIdentity * pid,
-           void *value)
+free_peer (void *cls, const struct GNUNET_PeerIdentity *pid, void *value)
 {
   struct Peer *pos = value;
 
   GNUNET_break (NULL == pos->mq);
   GNUNET_break (GNUNET_OK ==
-                GNUNET_CONTAINER_multipeermap_remove (peers,
-                                                      pid,
-                                                      pos));
+                GNUNET_CONTAINER_multipeermap_remove (peers, pid, pos));
   if (NULL != pos->hello_delay_task)
   {
     GNUNET_SCHEDULER_cancel (pos->hello_delay_task);
@@ -305,17 +299,13 @@ attempt_connect (struct Peer *pos)
 {
   uint32_t strength;
 
-  if (0 ==
-      memcmp (&my_identity,
-              &pos->pid,
-              sizeof (struct GNUNET_PeerIdentity)))
+  if (0 == GNUNET_memcmp (&my_identity, &pos->pid))
     return; /* This is myself, nothing to do. */
   if (connection_count < target_connection_count)
     strength = 1;
   else
     strength = 0;
-  if ( (friend_count < minimum_friend_count) ||
-       (GNUNET_YES == friends_only) )
+  if ((friend_count < minimum_friend_count) || (GNUNET_YES == friends_only))
   {
     if (pos->is_friend)
       strength += 10; /* urgently needed */
@@ -344,9 +334,7 @@ attempt_connect (struct Peer *pos)
                               gettext_noop ("# connect requests issued to ATS"),
                               1,
                               GNUNET_NO);
-    pos->sh = GNUNET_ATS_connectivity_suggest (ats,
-                                               &pos->pid,
-                                               strength);
+    pos->sh = GNUNET_ATS_connectivity_suggest (ats, &pos->pid, strength);
   }
 }
 
@@ -372,15 +360,14 @@ make_peer (const struct GNUNET_PeerIdentity *peer,
   if (NULL != hello)
   {
     ret->hello = GNUNET_malloc (GNUNET_HELLO_size (hello));
-    GNUNET_memcpy (ret->hello,
-		   hello,
-		   GNUNET_HELLO_size (hello));
+    GNUNET_memcpy (ret->hello, hello, GNUNET_HELLO_size (hello));
   }
   GNUNET_break (GNUNET_OK ==
-                GNUNET_CONTAINER_multipeermap_put (peers,
-                                                   peer,
-                                                   ret,
-                                                   GNUNET_CONTAINER_MULTIHASHMAPOPTION_UNIQUE_ONLY));
+                GNUNET_CONTAINER_multipeermap_put (
+                  peers,
+                  peer,
+                  ret,
+                  GNUNET_CONTAINER_MULTIHASHMAPOPTION_UNIQUE_ONLY));
   return ret;
 }
 
@@ -404,12 +391,9 @@ setup_filter (struct Peer *peer)
    * any case; hence 64, 5 as bloomfilter parameters. */
   peer->filter = GNUNET_CONTAINER_bloomfilter_init (NULL, 64, 5);
   peer->filter_expiration =
-      GNUNET_TIME_relative_to_absolute
-      (HELLO_ADVERTISEMENT_MIN_REPEAT_FREQUENCY);
+    GNUNET_TIME_relative_to_absolute (HELLO_ADVERTISEMENT_MIN_REPEAT_FREQUENCY);
   /* never send a peer its own HELLO */
-  GNUNET_CRYPTO_hash (&peer->pid,
-                      sizeof (struct GNUNET_PeerIdentity),
-                      &hc);
+  GNUNET_CRYPTO_hash (&peer->pid, sizeof (struct GNUNET_PeerIdentity), &hc);
   GNUNET_CONTAINER_bloomfilter_add (peer->filter, &hc);
 }
 
@@ -474,10 +458,9 @@ find_advertisable_hello (void *cls,
   if (hs > fah->max_size)
     return GNUNET_YES;
   GNUNET_CRYPTO_hash (&fah->peer->pid,
-		      sizeof (struct GNUNET_PeerIdentity), &hc);
-  if (GNUNET_NO ==
-      GNUNET_CONTAINER_bloomfilter_test (pos->filter,
-                                         &hc))
+                      sizeof (struct GNUNET_PeerIdentity),
+                      &hc);
+  if (GNUNET_NO == GNUNET_CONTAINER_bloomfilter_test (pos->filter, &hc))
     fah->result = pos;
   return GNUNET_YES;
 }
@@ -506,13 +489,9 @@ schedule_next_hello (void *cls)
   fah.result = NULL;
   fah.max_size = GNUNET_MAX_MESSAGE_SIZE - 1;
   fah.next_adv = GNUNET_TIME_UNIT_FOREVER_REL;
-  GNUNET_CONTAINER_multipeermap_iterate (peers,
-                                         &find_advertisable_hello,
-                                         &fah);
+  GNUNET_CONTAINER_multipeermap_iterate (peers, &find_advertisable_hello, &fah);
   pl->hello_delay_task =
-      GNUNET_SCHEDULER_add_delayed (fah.next_adv,
-                                    &schedule_next_hello,
-                                    pl);
+    GNUNET_SCHEDULER_add_delayed (fah.next_adv, &schedule_next_hello, pl);
   if (NULL == fah.result)
     return;
   delay = GNUNET_TIME_absolute_get_remaining (pl->next_hello_allowed);
@@ -521,31 +500,25 @@ schedule_next_hello (void *cls)
 
   want = GNUNET_HELLO_size (fah.result->hello);
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
-	      "Sending HELLO with %u bytes",
-	      (unsigned int) want);
+              "Sending HELLO with %u bytes",
+              (unsigned int) want);
   env = GNUNET_MQ_msg_copy (&fah.result->hello->header);
-  GNUNET_MQ_send (pl->mq,
-		  env);
+  GNUNET_MQ_send (pl->mq, env);
 
   /* avoid sending this one again soon */
-  GNUNET_CRYPTO_hash (&pl->pid,
-		      sizeof (struct GNUNET_PeerIdentity),
-		      &hc);
-  GNUNET_CONTAINER_bloomfilter_add (fah.result->filter,
-				    &hc);
+  GNUNET_CRYPTO_hash (&pl->pid, sizeof (struct GNUNET_PeerIdentity), &hc);
+  GNUNET_CONTAINER_bloomfilter_add (fah.result->filter, &hc);
 
   GNUNET_STATISTICS_update (stats,
-			    gettext_noop ("# HELLO messages gossipped"),
-			    1,
-			    GNUNET_NO);
+                            gettext_noop ("# HELLO messages gossipped"),
+                            1,
+                            GNUNET_NO);
   /* prepare to send the next one */
-  pl->next_hello_allowed
-    = GNUNET_TIME_relative_to_absolute (HELLO_ADVERTISEMENT_MIN_FREQUENCY);
+  pl->next_hello_allowed =
+    GNUNET_TIME_relative_to_absolute (HELLO_ADVERTISEMENT_MIN_FREQUENCY);
   if (NULL != pl->hello_delay_task)
     GNUNET_SCHEDULER_cancel (pl->hello_delay_task);
-  pl->hello_delay_task
-    = GNUNET_SCHEDULER_add_now (&schedule_next_hello,
-				pl);
+  pl->hello_delay_task = GNUNET_SCHEDULER_add_now (&schedule_next_hello, pl);
 }
 
 
@@ -577,7 +550,7 @@ reschedule_hellos (void *cls,
     peer->hello_delay_task = NULL;
   }
   peer->hello_delay_task =
-      GNUNET_SCHEDULER_add_now (&schedule_next_hello, peer);
+    GNUNET_SCHEDULER_add_now (&schedule_next_hello, peer);
   return GNUNET_YES;
 }
 
@@ -593,37 +566,25 @@ reschedule_hellos (void *cls,
 static void *
 connect_notify (void *cls,
                 const struct GNUNET_PeerIdentity *peer,
-		struct GNUNET_MQ_Handle *mq)
+                struct GNUNET_MQ_Handle *mq)
 {
   struct Peer *pos;
-  uint64_t flags;
-  const void *extra;
 
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
               "Core told us that we are connecting to `%s'\n",
               GNUNET_i2s (peer));
-  if (0 == memcmp (&my_identity,
-                   peer,
-                   sizeof (struct GNUNET_PeerIdentity)))
+  if (0 == GNUNET_memcmp (&my_identity, peer))
     return NULL;
-  extra = GNUNET_CORE_get_mq_options (GNUNET_YES,
-				      GNUNET_CORE_PRIO_BEST_EFFORT,
-				      &flags);
-  GNUNET_MQ_set_options (mq,
-			 flags,
-			 extra);
+  GNUNET_MQ_set_options (mq, GNUNET_MQ_PRIO_BEST_EFFORT);
   connection_count++;
   GNUNET_STATISTICS_set (stats,
                          gettext_noop ("# peers connected"),
                          connection_count,
                          GNUNET_NO);
-  pos = GNUNET_CONTAINER_multipeermap_get (peers,
-                                           peer);
+  pos = GNUNET_CONTAINER_multipeermap_get (peers, peer);
   if (NULL == pos)
   {
-    pos = make_peer (peer,
-                     NULL,
-                     GNUNET_NO);
+    pos = make_peer (peer, NULL, GNUNET_NO);
   }
   else
   {
@@ -633,17 +594,14 @@ connect_notify (void *cls,
   if (pos->is_friend)
   {
     friend_count++;
-    if ( (friend_count == minimum_friend_count) &&
-         (GNUNET_YES != friends_only) )
+    if ((friend_count == minimum_friend_count) && (GNUNET_YES != friends_only))
       whitelist_peers ();
     GNUNET_STATISTICS_set (stats,
                            gettext_noop ("# friends connected"),
                            friend_count,
                            GNUNET_NO);
   }
-  reschedule_hellos (NULL,
-                     peer,
-                     pos);
+  reschedule_hellos (NULL, peer, pos);
   return pos;
 }
 
@@ -657,9 +615,7 @@ connect_notify (void *cls,
  * @return #GNUNET_YES (continue to iterate)
  */
 static int
-try_add_peers (void *cls,
-               const struct GNUNET_PeerIdentity *pid,
-               void *value)
+try_add_peers (void *cls, const struct GNUNET_PeerIdentity *pid, void *value)
 {
   struct Peer *pos = value;
 
@@ -678,9 +634,7 @@ add_peer_task (void *cls)
 {
   add_task = NULL;
 
-  GNUNET_CONTAINER_multipeermap_iterate (peers,
-                                         &try_add_peers,
-                                         NULL);
+  GNUNET_CONTAINER_multipeermap_iterate (peers, &try_add_peers, NULL);
 }
 
 
@@ -694,7 +648,7 @@ add_peer_task (void *cls)
 static void
 disconnect_notify (void *cls,
                    const struct GNUNET_PeerIdentity *peer,
-		   void *internal_cls)
+                   void *internal_cls)
 {
   struct Peer *pos = internal_cls;
 
@@ -727,16 +681,12 @@ disconnect_notify (void *cls,
                            friend_count,
                            GNUNET_NO);
   }
-  if ( ( (connection_count < target_connection_count) ||
-         (friend_count < minimum_friend_count)) &&
-       (NULL == add_task) )
-    add_task = GNUNET_SCHEDULER_add_now (&add_peer_task,
-                                         NULL);
-  if ( (friend_count < minimum_friend_count) &&
-       (NULL == blacklist))
-    blacklist = GNUNET_TRANSPORT_blacklist (cfg,
-                                            &blacklist_check,
-                                            NULL);
+  if (((connection_count < target_connection_count) ||
+       (friend_count < minimum_friend_count)) &&
+      (NULL == add_task))
+    add_task = GNUNET_SCHEDULER_add_now (&add_peer_task, NULL);
+  if ((friend_count < minimum_friend_count) && (NULL == blacklist))
+    blacklist = GNUNET_TRANSPORT_blacklist (cfg, &blacklist_check, NULL);
 }
 
 
@@ -781,39 +731,32 @@ consider_for_advertising (const struct GNUNET_HELLO_Message *hello)
     GNUNET_break (0);
     return;
   }
-  if (0 == memcmp (&pid,
-                   &my_identity,
-                   sizeof (struct GNUNET_PeerIdentity)))
-    return;                     /* that's me! */
+  if (0 == GNUNET_memcmp (&pid, &my_identity))
+    return; /* that's me! */
   have_address = GNUNET_NO;
   GNUNET_HELLO_iterate_addresses (hello,
                                   GNUNET_NO,
                                   &address_iterator,
                                   &have_address);
   if (GNUNET_NO == have_address)
-    return;                     /* no point in advertising this one... */
+    return; /* no point in advertising this one... */
   peer = GNUNET_CONTAINER_multipeermap_get (peers, &pid);
   if (NULL == peer)
   {
-    peer = make_peer (&pid,
-                      hello,
-                      GNUNET_NO);
+    peer = make_peer (&pid, hello, GNUNET_NO);
   }
   else if (NULL != peer->hello)
   {
-    dt = GNUNET_HELLO_equals (peer->hello,
-                              hello,
-                              GNUNET_TIME_absolute_get ());
+    dt = GNUNET_HELLO_equals (peer->hello, hello, GNUNET_TIME_absolute_get ());
     if (dt.abs_value_us == GNUNET_TIME_UNIT_FOREVER_ABS.abs_value_us)
-      return;                   /* nothing new here */
+      return; /* nothing new here */
   }
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
               "Found HELLO from peer `%s' for advertising\n",
               GNUNET_i2s (&pid));
   if (NULL != peer->hello)
   {
-    nh = GNUNET_HELLO_merge (peer->hello,
-                             hello);
+    nh = GNUNET_HELLO_merge (peer->hello, hello);
     GNUNET_free (peer->hello);
     peer->hello = nh;
   }
@@ -821,9 +764,7 @@ consider_for_advertising (const struct GNUNET_HELLO_Message *hello)
   {
     size = GNUNET_HELLO_size (hello);
     peer->hello = GNUNET_malloc (size);
-    GNUNET_memcpy (peer->hello,
-            hello,
-            size);
+    GNUNET_memcpy (peer->hello, hello, size);
   }
   if (NULL != peer->filter)
   {
@@ -833,9 +774,7 @@ consider_for_advertising (const struct GNUNET_HELLO_Message *hello)
   setup_filter (peer);
   /* since we have a new HELLO to pick from, re-schedule all
    * HELLO requests that are not bound by the HELLO send rate! */
-  GNUNET_CONTAINER_multipeermap_iterate (peers,
-                                         &reschedule_hellos,
-                                         peer);
+  GNUNET_CONTAINER_multipeermap_iterate (peers, &reschedule_hellos, peer);
 }
 
 
@@ -859,25 +798,20 @@ process_peer (void *cls,
   if (NULL != err_msg)
   {
     GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
-                _("Error in communication with PEERINFO service: %s\n"),
+                _ ("Error in communication with PEERINFO service: %s\n"),
                 err_msg);
     GNUNET_PEERINFO_notify_cancel (peerinfo_notify);
-    peerinfo_notify = GNUNET_PEERINFO_notify (cfg,
-                                              GNUNET_NO,
-                                              &process_peer,
-                                              NULL);
+    peerinfo_notify =
+      GNUNET_PEERINFO_notify (cfg, GNUNET_NO, &process_peer, NULL);
     return;
   }
   GNUNET_assert (NULL != peer);
-  if (0 == memcmp (&my_identity,
-                   peer,
-                   sizeof (struct GNUNET_PeerIdentity)))
-    return;                     /* that's me! */
+  if (0 == GNUNET_memcmp (&my_identity, peer))
+    return; /* that's me! */
   if (NULL == hello)
   {
     /* free existing HELLO, if any */
-    pos = GNUNET_CONTAINER_multipeermap_get (peers,
-                                             peer);
+    pos = GNUNET_CONTAINER_multipeermap_get (peers, peer);
     if (NULL != pos)
     {
       GNUNET_free_non_null (pos->hello);
@@ -887,21 +821,15 @@ process_peer (void *cls,
         GNUNET_CONTAINER_bloomfilter_free (pos->filter);
         pos->filter = NULL;
       }
-      if ( (NULL == pos->mq) &&
-           (GNUNET_NO == pos->is_friend) )
-        free_peer (NULL,
-                   &pos->pid,
-                   pos);
+      if ((NULL == pos->mq) && (GNUNET_NO == pos->is_friend))
+        free_peer (NULL, &pos->pid, pos);
     }
     return;
   }
   consider_for_advertising (hello);
-  pos = GNUNET_CONTAINER_multipeermap_get (peers,
-                                           peer);
+  pos = GNUNET_CONTAINER_multipeermap_get (peers, peer);
   if (NULL == pos)
-    pos = make_peer (peer,
-                     hello,
-                     GNUNET_NO);
+    pos = make_peer (peer, hello, GNUNET_NO);
   attempt_connect (pos);
 }
 
@@ -914,24 +842,20 @@ process_peer (void *cls,
  * @param my_id ID of this peer, NULL if we failed
  */
 static void
-core_init (void *cls,
-           const struct GNUNET_PeerIdentity *my_id)
+core_init (void *cls, const struct GNUNET_PeerIdentity *my_id)
 {
   if (NULL == my_id)
   {
-    GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                _("Failed to connect to core service, can not manage topology!\n"));
+    GNUNET_log (
+      GNUNET_ERROR_TYPE_ERROR,
+      _ ("Failed to connect to core service, can not manage topology!\n"));
     GNUNET_SCHEDULER_shutdown ();
     return;
   }
   my_identity = *my_id;
-  GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
-	      "I am peer `%s'\n",
-	      GNUNET_i2s (my_id));
-  peerinfo_notify = GNUNET_PEERINFO_notify (cfg,
-                                            GNUNET_NO,
-					    &process_peer,
-                                            NULL);
+  GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "I am peer `%s'\n", GNUNET_i2s (my_id));
+  peerinfo_notify =
+    GNUNET_PEERINFO_notify (cfg, GNUNET_NO, &process_peer, NULL);
 }
 
 
@@ -942,25 +866,22 @@ core_init (void *cls,
  * @param pid identity of the friend
  */
 static void
-handle_friend (void *cls,
-               const struct GNUNET_PeerIdentity *pid)
+handle_friend (void *cls, const struct GNUNET_PeerIdentity *pid)
 {
   unsigned int *entries_found = cls;
   struct Peer *fl;
 
-  if (0 == memcmp (pid,
-                   &my_identity,
-                   sizeof (struct GNUNET_PeerIdentity)))
+  if (0 == GNUNET_memcmp (pid, &my_identity))
   {
     GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
-                _("Found myself `%s' in friend list (useless, ignored)\n"),
+                _ ("Found myself `%s' in friend list (useless, ignored)\n"),
                 GNUNET_i2s (pid));
     return;
   }
   (*entries_found)++;
   fl = make_peer (pid, NULL, GNUNET_YES);
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
-              _("Found friend `%s' in configuration\n"),
+              _ ("Found friend `%s' in configuration\n"),
               GNUNET_i2s (&fl->pid));
 }
 
@@ -974,31 +895,30 @@ read_friends_file (const struct GNUNET_CONFIGURATION_Handle *cfg)
   unsigned int entries_found;
 
   entries_found = 0;
-  if (GNUNET_OK !=
-      GNUNET_FRIENDS_parse (cfg,
-                            &handle_friend,
-                            &entries_found))
+  if (GNUNET_OK != GNUNET_FRIENDS_parse (cfg, &handle_friend, &entries_found))
   {
-    if ( (GNUNET_YES == friends_only) ||
-         (minimum_friend_count > 0))
+    if ((GNUNET_YES == friends_only) || (minimum_friend_count > 0))
       GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
-                  _("Encountered errors parsing friends list!\n"));
+                  _ ("Encountered errors parsing friends list!\n"));
   }
   GNUNET_STATISTICS_update (stats,
                             gettext_noop ("# friends in configuration"),
                             entries_found,
                             GNUNET_NO);
-  if ( (minimum_friend_count > entries_found) &&
-       (GNUNET_NO == friends_only) )
+  if ((minimum_friend_count > entries_found) && (GNUNET_NO == friends_only))
   {
-    GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
-                _("Fewer friends specified than required by minimum friend count. Will only connect to friends.\n"));
+    GNUNET_log (
+      GNUNET_ERROR_TYPE_WARNING,
+      _ (
+        "Fewer friends specified than required by minimum friend count. Will only connect to friends.\n"));
   }
-  if ( (minimum_friend_count > target_connection_count) &&
-       (GNUNET_NO == friends_only))
+  if ((minimum_friend_count > target_connection_count) &&
+      (GNUNET_NO == friends_only))
   {
-    GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
-                _("More friendly connections required than target total number of connections.\n"));
+    GNUNET_log (
+      GNUNET_ERROR_TYPE_WARNING,
+      _ (
+        "More friendly connections required than target total number of connections.\n"));
   }
 }
 
@@ -1013,14 +933,11 @@ read_friends_file (const struct GNUNET_CONFIGURATION_Handle *cfg)
  *         #GNUNET_SYSERR if @a message is invalid
  */
 static int
-check_hello (void *cls,
-	     const struct GNUNET_HELLO_Message *message)
+check_hello (void *cls, const struct GNUNET_HELLO_Message *message)
 {
   struct GNUNET_PeerIdentity pid;
 
-  if (GNUNET_OK !=
-      GNUNET_HELLO_get_id (message,
-			   &pid))
+  if (GNUNET_OK != GNUNET_HELLO_get_id (message, &pid))
   {
     GNUNET_break_op (0);
     return GNUNET_SYSERR;
@@ -1037,8 +954,7 @@ check_hello (void *cls,
  * @param message the actual HELLO message
  */
 static void
-handle_hello (void *cls,
-	      const struct GNUNET_HELLO_Message *message)
+handle_hello (void *cls, const struct GNUNET_HELLO_Message *message)
 {
   const struct GNUNET_PeerIdentity *other = cls;
   struct Peer *peer;
@@ -1047,34 +963,26 @@ handle_hello (void *cls,
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
               "Received encrypted HELLO from peer `%s'",
               GNUNET_i2s (other));
-  GNUNET_assert (GNUNET_OK ==
-		 GNUNET_HELLO_get_id (message,
-				      &pid));
+  GNUNET_assert (GNUNET_OK == GNUNET_HELLO_get_id (message, &pid));
   GNUNET_STATISTICS_update (stats,
                             gettext_noop ("# HELLO messages received"),
                             1,
                             GNUNET_NO);
-  peer = GNUNET_CONTAINER_multipeermap_get (peers,
-					    &pid);
+  peer = GNUNET_CONTAINER_multipeermap_get (peers, &pid);
   if (NULL == peer)
   {
-    if ( (GNUNET_YES == friends_only) ||
-         (friend_count < minimum_friend_count) )
+    if ((GNUNET_YES == friends_only) || (friend_count < minimum_friend_count))
       return;
   }
   else
   {
-    if ( (GNUNET_YES != peer->is_friend) &&
-         (GNUNET_YES == friends_only) )
+    if ((GNUNET_YES != peer->is_friend) && (GNUNET_YES == friends_only))
       return;
     if ((GNUNET_YES != peer->is_friend) &&
         (friend_count < minimum_friend_count))
       return;
   }
-  (void) GNUNET_PEERINFO_add_peer (pi,
-                                   message,
-                                   NULL,
-                                   NULL);
+  (void) GNUNET_PEERINFO_add_peer (pi, message, NULL, NULL);
 }
 
 
@@ -1108,9 +1016,7 @@ cleaning_task (void *cls)
     GNUNET_TRANSPORT_offer_hello_cancel (oh);
     oh = NULL;
   }
-  GNUNET_CONTAINER_multipeermap_iterate (peers,
-                                         &free_peer,
-                                         NULL);
+  GNUNET_CONTAINER_multipeermap_iterate (peers, &free_peer, NULL);
   GNUNET_CONTAINER_multipeermap_destroy (peers);
   peers = NULL;
   if (NULL != ats)
@@ -1145,26 +1051,22 @@ run (void *cls,
      const char *cfgfile,
      const struct GNUNET_CONFIGURATION_Handle *c)
 {
-  struct GNUNET_MQ_MessageHandler handlers[] = {
-    GNUNET_MQ_hd_var_size (hello,
-                           GNUNET_MESSAGE_TYPE_HELLO,
-                           struct GNUNET_HELLO_Message,
-                           NULL),
-    GNUNET_MQ_handler_end ()
-  };
+  struct GNUNET_MQ_MessageHandler handlers[] =
+    {GNUNET_MQ_hd_var_size (hello,
+                            GNUNET_MESSAGE_TYPE_HELLO,
+                            struct GNUNET_HELLO_Message,
+                            NULL),
+     GNUNET_MQ_handler_end ()};
   unsigned long long opt;
 
   cfg = c;
   stats = GNUNET_STATISTICS_create ("topology", cfg);
   friends_only =
-      GNUNET_CONFIGURATION_get_value_yesno (cfg,
-                                            "TOPOLOGY",
-                                            "FRIENDS-ONLY");
-  if (GNUNET_OK !=
-      GNUNET_CONFIGURATION_get_value_number (cfg,
-                                             "TOPOLOGY",
-                                             "MINIMUM-FRIENDS",
-                                             &opt))
+    GNUNET_CONFIGURATION_get_value_yesno (cfg, "TOPOLOGY", "FRIENDS-ONLY");
+  if (GNUNET_OK != GNUNET_CONFIGURATION_get_value_number (cfg,
+                                                          "TOPOLOGY",
+                                                          "MINIMUM-FRIENDS",
+                                                          &opt))
     opt = 0;
   minimum_friend_count = (unsigned int) opt;
   if (GNUNET_OK !=
@@ -1181,25 +1083,21 @@ run (void *cls,
               "Topology would like %u connections with at least %u friends\n",
               target_connection_count,
               minimum_friend_count);
-  if ( (GNUNET_YES == friends_only) ||
-       (minimum_friend_count > 0))
-    blacklist = GNUNET_TRANSPORT_blacklist (cfg,
-                                            &blacklist_check,
-                                            NULL);
+  if ((GNUNET_YES == friends_only) || (minimum_friend_count > 0))
+    blacklist = GNUNET_TRANSPORT_blacklist (cfg, &blacklist_check, NULL);
   ats = GNUNET_ATS_connectivity_init (cfg);
   pi = GNUNET_PEERINFO_connect (cfg);
   handle = GNUNET_CORE_connect (cfg,
-				NULL,
-				&core_init,
-				&connect_notify,
-				&disconnect_notify,
-				handlers);
-  GNUNET_SCHEDULER_add_shutdown (&cleaning_task,
-				 NULL);
+                                NULL,
+                                &core_init,
+                                &connect_notify,
+                                &disconnect_notify,
+                                handlers);
+  GNUNET_SCHEDULER_add_shutdown (&cleaning_task, NULL);
   if (NULL == handle)
   {
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                _("Failed to connect to `%s' service.\n"),
+                _ ("Failed to connect to `%s' service.\n"),
                 "core");
     GNUNET_SCHEDULER_shutdown ();
     return;
@@ -1215,24 +1113,25 @@ run (void *cls,
  * @return 0 ok, 1 on error
  */
 int
-main (int argc,
-      char *const *argv)
+main (int argc, char *const *argv)
 {
   static const struct GNUNET_GETOPT_CommandLineOption options[] = {
-    GNUNET_GETOPT_OPTION_END
-  };
+    GNUNET_GETOPT_OPTION_END};
   int ret;
 
   if (GNUNET_OK != GNUNET_STRINGS_get_utf8_args (argc, argv, &argc, &argv))
     return 2;
 
-  ret =
-      (GNUNET_OK ==
-       GNUNET_PROGRAM_run (argc, argv,
-                           "gnunet-daemon-topology",
-                           _("GNUnet topology control"),
-                           options, &run, NULL)) ? 0 : 1;
-  GNUNET_free ((void*) argv);
+  ret = (GNUNET_OK == GNUNET_PROGRAM_run (argc,
+                                          argv,
+                                          "gnunet-daemon-topology",
+                                          _ ("GNUnet topology control"),
+                                          options,
+                                          &run,
+                                          NULL))
+          ? 0
+          : 1;
+  GNUNET_free ((void *) argv);
   return ret;
 }
 
@@ -1243,8 +1142,7 @@ main (int argc,
 /**
  * MINIMIZE heap size (way below 128k) since this process doesn't need much.
  */
-void __attribute__ ((constructor))
-GNUNET_ARM_memory_init ()
+void __attribute__ ((constructor)) GNUNET_ARM_memory_init ()
 {
   mallopt (M_TRIM_THRESHOLD, 4 * 1024);
   mallopt (M_TOP_PAD, 1 * 1024);
