@@ -355,7 +355,7 @@ GNUNET_CONTAINER_multihashmap_get (
 int
 GNUNET_CONTAINER_multihashmap_iterate (
   struct GNUNET_CONTAINER_MultiHashMap *map,
-  GNUNET_CONTAINER_HashMapIterator it,
+  GNUNET_CONTAINER_MulitHashMapIteratorCallback it,
   void *it_cls)
 {
   int count;
@@ -876,7 +876,7 @@ int
 GNUNET_CONTAINER_multihashmap_get_multiple (
   struct GNUNET_CONTAINER_MultiHashMap *map,
   const struct GNUNET_HashCode *key,
-  GNUNET_CONTAINER_HashMapIterator it,
+  GNUNET_CONTAINER_MulitHashMapIteratorCallback it,
   void *it_cls)
 {
   int count;
@@ -942,7 +942,7 @@ GNUNET_CONTAINER_multihashmap_get_multiple (
 unsigned int
 GNUNET_CONTAINER_multihashmap_get_random (
   const struct GNUNET_CONTAINER_MultiHashMap *map,
-  GNUNET_CONTAINER_HashMapIterator it,
+  GNUNET_CONTAINER_MulitHashMapIteratorCallback it,
   void *it_cls)
 {
   unsigned int off;
