@@ -194,7 +194,7 @@ int
 main (int argc, char *argv[])
 {
   eval (1024); 
-  /* eval (2048); */
+  eval (2048); 
   /* eval (4096); */
   return 0;
 }
